import { ListItemText, MenuItem, Select, SelectChangeEvent } from "@mui/material";
import { useState } from "react";
import { TTag } from "../lib/types";

export type TTagSelectorProps = {
    tags: TTag[];
}

export function TagSelector(props: TTagSelectorProps) {
    const [selectedTags, setSelectedTags] = useState<string[]>([]);

    const handleChange = (event: SelectChangeEvent<typeof selectedTags>) => {
        const { value } = event.target;
        setSelectedTags(typeof value == "string" ? value.split(",") : value);
    };

    return(
        <Select
        multiple
        value={selectedTags}
        onChange={handleChange}
        renderValue={(selected) => selected.join(', ')}>
            {props.tags.map((tag) => (
                <MenuItem key={tag.id} value={tag.name}>
                    <ListItemText primary={tag.name} />
                </MenuItem>
            ))}
        </Select>
    );
}